#
# spec file for package mysql-connector-java
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mysql-connector-java
Version:        5.1.35
Release:        9.3
Summary:        Official JDBC Driver for MySQL
License:        GPL-2.0+
Group:          Development/Libraries/Java
Url:            http://dev.mysql.com/downloads/connector/j/
Source0:        %{name}-%{version}-suse.tar.xz
# Script to repack upstream tarball
# ./generate-tarball.sh VERSION
Source99:       generate-tarball.sh
# PATCH-FIX-UPSTREAM: do not strictly require jdk6 to compile
Patch0:         jdk6-check-use-jdk7.patch
# PATCH-FIX-UPSTREAM: do not require hibernate4 to actually just build
Patch1:         extra-libs-build.patch
# PATCH-FIX-SUSE: do not build jdbc3 driver needing too old java
Patch2:         no-jdk5-requirement.patch
# PATCH-FIX-UPSTREAM: build with jdbc4.1 and also with new javac
Patch3:         mysql-connector-java-jdbc-4.1.patch
# PATCH-FIX-UPSTREAM: do not lose classpath during tests build
Patch4:         use-classpath-in-tests.patch
BuildRequires:  ant
BuildRequires:  ant-contrib
BuildRequires:  apache-commons-logging
BuildRequires:  geronimo-jta-1_1-api
BuildRequires:  java-devel >= 1.6.0
BuildRequires:  javapackages-tools
BuildRequires:  junit
BuildRequires:  log4j-mini
BuildRequires:  slf4j
BuildRequires:  xz
Requires:       jta >= 1.0
Requires:       log4j
Requires:       slf4j
Provides:       mm.mysql = %{version}
Obsoletes:      mm.mysql < %{version}
# manual is no longer distributed
Provides:       %{name}-manual = %{version}
Obsoletes:      %{name}-manual < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
MySQL Connector/J is a native Java driver that converts JDBC (Java
Database Connectivity) calls into the network protocol used by the
MySQL database. It lets developers working with the Java programming
language easily build programs and applets that interact with MySQL and
connect all corporate data, even in a heterogeneous environment. MySQL
Connector/J is a Type IV JDBC driver and has a complete JDBC feature
set that supports the capabilities of MySQL.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

# dup
rm -f README
# wrong end of line encoding
sed -i -e 's/.$//' README.txt

%build
# disable jboss integration
rm -rf src/com/mysql/jdbc/integration/jboss
rm src/testsuite/regression/ConnectionRegressionTest.java
rm src/testsuite/regression/DataSourceRegressionTest.java
rm src/testsuite/simple/ReadOnlyCallableStatementTest.java
rm src/testsuite/simple/jdbc4/StatementsTest.java
# disable hibernate4 integration
rm -rf src/com/mysql/fabric/hibernate
rm -rf src/demo

export CLASSPATH=$(build-classpath \
    ant-contrib \
    commons-logging \
    slf4j \
    jdbc-stdext\
    jta \
    junit \
    log4j)
ant \
    -Dant.build.javac.source=1.5 -Dant.build.javac.target=1.5 \
    -DbuildDir=build-mysql-jdbc \
    -DdistDir=dist-mysql-jdbc \
    -Dcom.mysql.jdbc.jdk6.javac="%{javac}" \
    -Dcom.mysql.jdbc.jdk6.java="%{java}" \
    dist

%install
install -d -m 755 %{buildroot}%{_javadir}

install ./build-mysql-jdbc/%{name}-%{version}-SNAPSHOT/%{name}-%{version}-SNAPSHOT-bin.jar \
        %{buildroot}%{_javadir}/%{name}.jar

rm -rf %{buildroot}%{name}-%{version}/docs/release-test-output

# Install the Maven build information
install -d -m 755 %{buildroot}%{_mavenpomdir}
install -pm 644 src/doc/sources/pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
sed -i 's/>@.*</>%{version}</' %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom

%add_maven_depmap JPP-%{name}.pom %{name}.jar

%files
%defattr(0644,root,root,0755)
%doc CHANGES COPYING README.txt
%attr(0644,root,root) %{_javadir}/%{name}.jar
%config(noreplace) %{_mavendepmapfragdir}/*
%{_mavenpomdir}/*.pom

%changelog
* Thu Jun 11 2015 tchvatal@suse.com
- Fix the patches to allow jdbc3 build and reenable it:
  * mysql-connector-java-jdbc-4.1.patch
  * no-jdk5-requirement.patch
* Tue Apr 21 2015 tchvatal@suse.com
- Update to 5.1.35 (see CHANGES for full list of issues)
  bnc#927981 CVE-2015-2575:
  * http://dev.mysql.com/doc/relnotes/connector-j/en/news-5-1.html
- Remove not applicable patch:
  * mysql-connector-java-7-jdbc-4.1.patch
- Do not explicitely check for jdk6 but be happy with 7 and 8:
  * jdk6-check-use-jdk7.patch
- Do not require hibernate4 to actually build:
  * extra-libs-build.patch
- Do not build jdk5 depending jdbc3:
  * no-jdk5-requirement.patch
- Add and rebase jdbc4.1 patch:
  * mysql-connector-java-jdbc-4.1.patch
- Add new patch to build tests:
  * use-classpath-in-tests.patch
* Fri Jun 27 2014 tchvatal@suse.com
- Cleanup with spec-cleaner
- Try to build on SLE_11
* Thu Sep 19 2013 mvyskocil@suse.com
- update to 5.1.25 (see CHANGES for full list)
  * support for Connection Attributes when used with MySQL Server versions (5.6+).
  5.1.24
  * support of password expiration protocol. This introduces new boolean
    connection property disconnectOnExpiredPasswords.
  5.1.23
  * added support of password expiration protocol.
  * driver now allows the mechanism for caching MySQL server configuration
    values replaceable at runtime.
  * Connection.setReadOnly() will take advantage of server-side support for
    read-only transactions present in MySQL-5.6 and newer. Calling .isReadOnly()
    will incur a round-trip if useLocalSessionState.
  5.1.22
  * support of ON UPDATE CURRENT_TIMESTAMP for TIMESTAMP and DATETIME fields.
  5.1.21
  * new built-in authentication plugin
    com.mysql.jdbc.authentication.Sha256PasswordPlugin ("sha256_password").
  * Added new built-in authentication plugin
    com.mysql.jdbc.authentication.MysqlClearPasswordPlugin ("mysql_clear_password").
    It allows C/J based clients to connect to MySQL accounts.
  * the ability to add new client-side prepared statement parse info caches
  * implemented several JDBC-4.1 methods from Java-7:
  5.1.19:
  * Added support for pluggable authentication via the com.mysql.jdbc.AuthenticationPlugin
- rebase and rename mysql-connector-java-5.1.19-java7.patch to
  * mysql-connector-java-7-jdbc-4.1.patch
* Fri Sep 13 2013 pgajdos@suse.com
- add jpackages-tools to buildrequires
* Fri Aug 23 2013 mvyskocil@suse.com
- use add_maven_depmap provided by javapackages-tools
* Wed Jun 20 2012 mvyskocil@suse.cz
- build require java-devel >= 1.6.0 as well
* Mon Jun 18 2012 mvyskocil@suse.cz
- fix a build with jdk7 (build jdbc 3.0 with gcj)
- remove some obsoleted macros (gcj, jboss)
- remove jars from source file as well
* Fri May  4 2012 mvyskocil@suse.cz
- remove the docs/ from source tarball due license issues
* Fri Apr 27 2012 mvyskocil@suse.cz
- update to 5.1.19
  * plugable authentication via com.mysql.jdbc.AuthenticationPlugin
  * retrieve servet charset name using index
  * ability to determine if the connection is against server on the same host
  * added slf4j logging adapter
  * and many more features and bugfixes
- removed -javadoc patch and package
- add maven pom
* Thu Sep 11 2008 anosek@suse.cz
- updated to version 5.1.6
  - introduces driver which conforms to the JDBC 4.0 specifications.
    However this was disabled because of missing dependencies
- dropped obsoleted patch (build_xml.patch)
- added patch (disableJDBC4.patch) taken from Debian
* Thu Aug  7 2008 mvyskocil@suse.cz
- update to the 5.0.8 (improved spec from jpackage.org)
  - fix of [bnc#99151]
- added two new subpackages (javadoc and manual)
- removed the dependency on jboss4
- add a support for build with java6 and java5 together (ia64 build fix)
- use source="1.5" and target="1.5"
* Thu Jul 17 2008 coolo@suse.de
- trying to avoid another build cycle
* Wed Sep 27 2006 skh@suse.de
- don't use icecream
- use source="1.4" and target="1.4" for build with java 1.5
* Tue Feb  7 2006 jsmeix@suse.de
- Current version 3.1.12 from JPackage.org
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jul 28 2005 jsmeix@suse.de
- Adjustments in the spec file.
* Mon Jul 18 2005 jsmeix@suse.de
- Current version 3.1.8 from JPackage.org
* Fri Feb 18 2005 skh@suse.de
- update to version 3.1.6
- don't use icecream
* Thu Sep  2 2004 skh@suse.de
- Initial package created with version 3.0.11 (JPackage 1.5)
